import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:signage_app/const/colors.dart';
import 'package:signage_app/const/dimens.dart';
import 'package:signage_app/provider.dart';

class DisplayDate extends ConsumerWidget {
  const DisplayDate(
      {super.key, this.size = const Size(double.infinity, double.infinity)});

  final Size size;

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final Size widgetSize = MediaQuery.of(context).size;
    final dateStyle = TextStyle(
        fontSize: widgetSize.height * dateFontSizeRatio,
        color: dateAndTimeTextColor);
    final dateUnitStyle = TextStyle(
        fontSize: widgetSize.height * dateUnitFontSizeRatio,
        color: dateAndTimeTextColor);
    final presentDateTime = ref.watch(presentDateTimeProvider);

    return Container(
      alignment: const Alignment(dateAlignmentXRatio, 0),
      width: size.width,
      height: size.height,
      color: dateBackgroundColor,
      child: Text.rich(
        TextSpan(
          text: '${presentDateTime.year}',
          style: dateStyle,
          children: [
            TextSpan(text: ' 年', style: dateUnitStyle),
            TextSpan(text: '   ${presentDateTime.month}', style: dateStyle),
            TextSpan(text: ' 月', style: dateUnitStyle),
            TextSpan(text: '   ${presentDateTime.day}', style: dateStyle),
            TextSpan(text: ' 日', style: dateUnitStyle),
            TextSpan(
                text: '   ${'月火水木金土日'[presentDateTime.weekday - 1]}',
                style: dateStyle),
            TextSpan(text: ' 曜日', style: dateUnitStyle),
          ],
        ),
      ),
    );
  }
}
