import 'package:flutter/material.dart';
import 'package:video_player/video_player.dart';
import 'package:signage_app/const/config.dart';
import 'package:signage_app/const/dimens.dart';
import 'package:signage_app/widget/overlay_text.dart';

class Video extends StatefulWidget {
  const Video(
      {super.key, this.size = const Size(double.infinity, double.infinity)});

  final Size size;

  @override
  VideoState createState() => VideoState();
}

class VideoState extends State<Video> {
  late VideoPlayerController _controller;

  @override
  void initState() {
    super.initState();
    _controller = makeController(videoURI);
    _controller.setPlaybackSpeed(videoSpeed.toDouble());
    _controller.setLooping(true);
    _controller.initialize();
    _controller.play();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    final Size widgetSize = MediaQuery.of(context).size;
    final Size overlayTextContainerSize = Size(
        widgetSize.width * overlayTextWidthRatio,
        widgetSize.height * overlayTextHeightRatio);
    final double overlayTextFontSize = widgetSize.height * overlayFontSizeRatio;
    final double overlayTextStrokeWidth =
        widgetSize.height * textStrokeWidthRatio;

    return SizedBox(
        height: widget.size.height,
        width: widget.size.width,
        child: Stack(
          children: [
            VideoPlayer(_controller),
          Align(
            alignment: Alignment.topRight,
            child: Column(
              children: [
                Padding(
                  padding: EdgeInsets.only(
                    top: widgetSize.height * sideHeightPaddingRatio / 2,
                  ),
                ),
                overlayText(
                  videoOverlayText,
                overlayTextContainerSize,
                  overlayTextFontSize,
                  overlayTextStrokeWidth,
                ),
              ],
            ),
          )
        ],
      ),
    );
  }
}

VideoPlayerController makeController(String uri) {
  if (uri.contains('https://')) {
    return VideoPlayerController.network(uri);
  }
  return VideoPlayerController.asset(uri);
}
